@@ -383,9 +383,23 @@ int IOSAdministration::processDeviceConfig(Device *device, ConfigLine *command,
 				linePointer = addLine();
 
 				if ((strcmp(command->part(tempInt), "con") == 0) || (strcmp(command->part(tempInt), "concole") == 0))
+				{
 					linePointer->type = lineConsole;
+					linePointer->defaultSettings = false;
+					linePointer->ssh = false;
+					linePointer->telnet = false;
+					linePointer->rlogin = false;
+					linePointer->all = false;
+				}
 				else if ((strcmp(command->part(tempInt), "aux") == 0) || (strcmp(command->part(tempInt), "auxiliary") == 0))
+				{
 					linePointer->type = lineAUX;
+					linePointer->defaultSettings = false;
+					linePointer->ssh = false;
+					linePointer->telnet = false;
+					linePointer->rlogin = false;
+					linePointer->all = false;
+				}
 				else if (strcmp(command->part(tempInt), "tty") == 0)
 					linePointer->type = lineTTY;
 				else
@@ -515,6 +529,9 @@ int IOSAdministration::processDeviceConfig(Device *device, ConfigLine *command,
 				}
 				else
 				{
+					linePointer->ssh = false;
+					linePointer->telnet = false;
+					linePointer->rlogin = false;
 					linePointer->all = false;
 					while (tempInt < command->parts)
 					{
@@ -649,6 +666,11 @@ int IOSAdministration::processDefaults(Device *device)
 	cipherConfig *cipherPointer = 0;
 	string tempString;
 
+	// Disable services by default...
+	telnetEnabled = false;
+	sshEnabled = false;
+	rloginEnabled = false;
+
 	// Sort out CDP verison...
 	if (device->general != 0)
 	{
@@ -741,6 +763,7 @@ int IOSAdministration::processDefaults(Device *device)
 	linePointer = line;
 	while (linePointer != 0)
 	{
+
 		// If AAA is used, the login must be handled by AAA
 		if (aaaUsed == true)
 			linePointer->login = loginAuthentication;
