@@ -676,7 +676,7 @@ int IOSAuthentication::processDeviceConfig(Device *device, ConfigLine *command,
 		localUserPointer = getUser(command->part(tempInt));
 		if (localUserPointer->privilegeLevel.empty())
 			localUserPointer->privilegeLevel.assign("1");
-		tempInt += 2;
+		tempInt++;
 
 		while (tempInt < command->parts)
 		{
@@ -699,7 +699,7 @@ int IOSAuthentication::processDeviceConfig(Device *device, ConfigLine *command,
 			}
 
 			// Password...
-			else if (strcmp(command->part(tempInt), "password") == 0)
+			else if ((strcmp(command->part(tempInt), "password") == 0) || (strcmp(command->part(tempInt), "secret") == 0))
 			{
 				tempInt++;
 
