@@ -97,14 +97,15 @@ int IOSFilter::processDeviceConfig(Device *device, ConfigLine *command, char *li
 	int tempInt2 = 0;
 	bool specificProtocol = false;
 	bool icmpProtocol = false;
+	fpos_t filePosition;
 
 	if (strcmp(command->part(0), "no") != 0)
 	{
 
 		// IP Access List...
-		if ((strcmp(command->part(0), "ip") == 0) && (strcmp(command->part(1), "access-list") == 0))
+		if ((strcmp(command->part(0), "ip") == 0) && (strcmp(command->part(1), "access-list") == 0) && (strcmp(command->part(2), "log-update") != 0))
 		{
-			while ((strcmp(command->part(0), "!") != 0) && (feof(device->inputFile) == 0))
+			while ((strcmp(command->part(0), "!") != 0) && ((line[0] == ' ') || (strcmp(command->part(1), "access-list") == 0)) && (strcmp(command->part(2), "log-update") != 0) && (feof(device->inputFile) == 0))
 			{
 
 				// Access-List...
@@ -412,11 +413,15 @@ int IOSFilter::processDeviceConfig(Device *device, ConfigLine *command, char *li
 					device->lineNotProcessed(line);
 
 				// Read a line from the config...
+				fgetpos(device->inputFile, &filePosition);
 				device->readLine(line, lineSize);
 
 				// Split it up into parts...
 				command->setConfigLine(line);
 			}
+
+			// Set file position back
+			fsetpos(device->inputFile, &filePosition);
 		}
 
 		// Compiled Access List...
