@@ -350,7 +350,7 @@ int CiscoSecAdministration::processDeviceConfig(Device *device, ConfigLine *comm
 			printf("%sConsole Timeout Line:%s %s\n", device->config->COL_GREEN, device->config->COL_RESET, line);
 		tempInt += 2;
 		if (setting == true)
-			consoleTimeout = atoi(command->part(tempInt));
+			consoleTimeout = atoi(command->part(tempInt)) * 60;
 		else
 			consoleTimeout = 0;
 	}
@@ -421,7 +421,7 @@ int CiscoSecAdministration::processDeviceConfig(Device *device, ConfigLine *comm
 			if (setting == false)
 				sshTimeout = 300;
 			else
-				sshTimeout = atoi(command->part(tempInt));
+				sshTimeout = atoi(command->part(tempInt)) * 60;
 			sshSupported = true;
 			sshUpgrade = false;
 		}
@@ -463,7 +463,7 @@ int CiscoSecAdministration::processDeviceConfig(Device *device, ConfigLine *comm
 			device->lineNotProcessed(line);
 	}
 
-	// SSH...
+	// Telnet...
 	else if (strcmp(command->part(tempInt), "telnet") == 0)
 	{
 		tempInt++;
@@ -477,7 +477,7 @@ int CiscoSecAdministration::processDeviceConfig(Device *device, ConfigLine *comm
 			if (setting == false)
 				telnetTimeout = 300;
 			else
-				telnetTimeout = atoi(command->part(tempInt));
+				telnetTimeout = atoi(command->part(tempInt)) * 60;
 		}
 
 		// Telnet management hosts...
