@@ -531,7 +531,7 @@ int Administration::generateHTTPWeakHostSecurityIssue(Device *device, int weakCo
 	paragraphPointer = device->addParagraph(securityIssuePointer, Device::Impact);
 	device->addString(paragraphPointer, protoString.c_str());
 	paragraphPointer->paragraph.assign(i18n("With weak management host address restrictions, an attacker or malicious user with authentication credentials would be able to connect to the *DATA* service and logon. Furthermore, if a vulnerability was to be identified in the service the attacker would not be prevented from connecting to the service."));
-	if ((httpEnabled == false) || ((httpEnabled == true) && (httpsRedirect == true)))
+	if ((httpEnabled == true) && (httpsRedirect == false))
 	{
 		securityIssuePointer->impactRating = 6;			// MEDIUM
 		paragraphPointer = device->addParagraph(securityIssuePointer, Device::Impact);
@@ -549,11 +549,18 @@ int Administration::generateHTTPWeakHostSecurityIssue(Device *device, int weakCo
 	paragraphPointer = device->addParagraph(securityIssuePointer, Device::Recommendation);
 	device->addString(paragraphPointer, protoString.c_str());
 	device->addString(paragraphPointer, protoString.c_str());
-	paragraphPointer->paragraph.assign(i18n("*COMPANY* recommends that, if possible, the *DATA* service should be disabled and replaced with a cryptographically secure alternative. However, if the *DATA* service is required, *COMPANY* recommends that specific addresses for those hosts that require administrative access should be configured."));
-	if (strlen(configHTTPHostAccess) > 0)
+	if ((httpEnabled == true) && (httpsRedirect == false))
 	{
-		paragraphPointer = device->addParagraph(securityIssuePointer, Device::Recommendation);
-		paragraphPointer->paragraph.assign(configHTTPHostAccess);
+		paragraphPointer->paragraph.assign(i18n("*COMPANY* recommends that, if possible, the *DATA* service should be disabled and replaced with a cryptographically secure alternative. However, if the *DATA* service is required, *COMPANY* recommends that access should be restricted to only those host addresses that require administrative access."));
+		if (strlen(configHTTPHostAccess) > 0)
+		{
+			paragraphPointer = device->addParagraph(securityIssuePointer, Device::Recommendation);
+			paragraphPointer->paragraph.assign(configHTTPHostAccess);
+		}
+	}
+	else
+	{
+		paragraphPointer->paragraph.assign(i18n("*COMPANY* recommends that access should be restricted to only those host addresses that require administrative access."));
 	}
 
 	// Conclusions text...
