@@ -139,7 +139,7 @@ int Administration::generateConsoleTimeoutSecurityIssue(Device *device)
 		printf("    %s*%s [ISSUE] Long Console Connection Timeout\n", device->config->COL_BLUE, device->config->COL_RESET);
 
 	securityIssuePointer = device->addSecurityIssue();
-	if (connectionTimeout == 0)
+	if (consoleTimeout == 0)
 		securityIssuePointer->title.assign(i18n("No Console Connection Timeout"));
 	else
 		securityIssuePointer->title.assign(i18n("Long Console Connection Timeout"));
@@ -149,16 +149,16 @@ int Administration::generateConsoleTimeoutSecurityIssue(Device *device)
 	paragraphPointer = device->addParagraph(securityIssuePointer, Device::Finding);
 	paragraphPointer->paragraph.assign(i18n("The console connection timeout setting is used by *DEVICETYPE* devices to determine if a console connection is no longer being used and can be closed. The console connection could become unused if an administrator has not correctly terminated the connection and still remains logged into the console or they have left their computer without terminating the console connection."));
 	paragraphPointer = device->addParagraph(securityIssuePointer, Device::Finding);
-	if (connectionTimeout == 0)
+	if (consoleTimeout == 0)
 		paragraphPointer->paragraph.assign(i18n("*COMPANY* determined that there was no console connection timeout was configured on *DEVICENAME*."));
 	else
 	{
-		device->addString(paragraphPointer, device->timeToString(connectionTimeout));
+		device->addString(paragraphPointer, device->timeToString(consoleTimeout));
 		paragraphPointer->paragraph.assign(i18n("*COMPANY* determined that the console connection timeout on *DEVICENAME* was *DATA*."));
 	}
 
 	// Issue impact...
-	if (connectionTimeout == 0)
+	if (consoleTimeout == 0)
 		securityIssuePointer->impactRating = 9;			// CRTICICAL
 	else
 		securityIssuePointer->impactRating = 7;			// HIGH
@@ -182,7 +182,7 @@ int Administration::generateConsoleTimeoutSecurityIssue(Device *device)
 	}
 
 	// Conclusions text...
-	if (connectionTimeout == 0)
+	if (consoleTimeout == 0)
 		securityIssuePointer->conLine.append(i18n("no console connection timeout was configured"));
 	else
 		securityIssuePointer->conLine.append(i18n("a long console connection timeout was configured"));
