@@ -130,6 +130,15 @@ int Authentication::generateConfigLocalUserReport(Device *device)
 				case netscreenEncryption:
 					device->addTableData(paragraphPointer->table, i18n("NetScreen"));
 					break;
+				case md4Encryption:
+					device->addTableData(paragraphPointer->table, i18n("*ABBREV*MD4*-ABBREV*"));
+					break;
+				case ntEncryption:
+					device->addTableData(paragraphPointer->table, i18n("*ABBREV*NT*-ABBREV*"));
+					break;
+				case desEncryption:
+					device->addTableData(paragraphPointer->table, i18n("*ABBREV*DES*-ABBREV*"));
+					break;
 				default:
 					device->addTableData(paragraphPointer->table, i18n("*ABBREV*AES*-ABBREV*"));
 					break;
