@@ -35,7 +35,7 @@
 #include "report.h"
 
 
-int Report::writeText(const char *theText, Device::paragraphStruct *paragraph, bool expandAbbreviations)
+int Report::writeText(const char *theText, Device::paragraphStruct *paragraph, bool expandAbbreviations, bool hideMarkup)
 {
 	// Variables...
 	string outputString(outputFriendly(theText));
@@ -68,6 +68,7 @@ int Report::writeText(const char *theText, Device::paragraphStruct *paragraph, b
 			// Find abbreviation...
 			position2 = outputString.find("*-ABBREV*", position);
 			tempString2.assign(outputString.substr(position + 8, position2 - position - 8).c_str());
+
 			// Output abbreviation...
 			switch (device->addAbbreviation(tempString2.c_str(), expandAbbreviations))
 			{
@@ -75,17 +76,27 @@ int Report::writeText(const char *theText, Device::paragraphStruct *paragraph, b
 					switch (config->reportFormat)
 					{
 						case Config::XML:
-							tempString.assign("<abbrev expand=\"true\" long=\"");
-							tempString.append(device->getAbbreviation(tempString2.c_str()));
-							tempString.append("\" short=\"");
-							tempString.append(tempString2);
-							tempString.append("\" />"); 
+							if (hideMarkup == true)
+								tempString.assign(device->getAbbreviation(tempString2.c_str()));
+							else
+							{
+								tempString.assign("<abbrev expand=\"true\" long=\"");
+								tempString.append(device->getAbbreviation(tempString2.c_str()));
+								tempString.append("\" short=\"");
+								tempString.append(tempString2);
+								tempString.append("\" />"); 
+							}
 							break;
 						default:
-							tempString.assign(device->getAbbreviation(tempString2.c_str()));
-							tempString.append(" (");
-							tempString.append(tempString2);
-							tempString.append(")");
+							if (hideMarkup == true)
+								tempString.assign(device->getAbbreviation(tempString2.c_str()));
+							else
+							{
+								tempString.assign(device->getAbbreviation(tempString2.c_str()));
+								tempString.append(" (");
+								tempString.append(tempString2);
+								tempString.append(")");
+							}
 							break;
 					}
 					break;
@@ -93,11 +104,16 @@ int Report::writeText(const char *theText, Device::paragraphStruct *paragraph, b
 					switch (config->reportFormat)
 					{
 						case Config::XML:
-							tempString.assign("<abbrev expand=\"false\" long=\"");
-							tempString.append(device->getAbbreviation(tempString2.c_str()));
-							tempString.append("\" short=\"");
-							tempString.append(tempString2);
-							tempString.append("\" />"); 
+							if (hideMarkup == true)
+								tempString.assign(tempString2);
+							else
+							{
+								tempString.assign("<abbrev expand=\"false\" long=\"");
+								tempString.append(device->getAbbreviation(tempString2.c_str()));
+								tempString.append("\" short=\"");
+								tempString.append(tempString2);
+								tempString.append("\" />"); 
+							}
 							break;
 						default:
 							tempString.assign(tempString2);
